==> openjpa-parent-2.4.3-source-release.zip: openjpa-parent-2.4.3/openjpa-persistence-jdbc/src/test/java/org/apache/openjpa/persistence/jdbc/maps/spec_10_1_26_ex0/Employee3.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.    
 */
package org.apache.openjpa.persistence.jdbc.maps.spec_10_1_26_ex0;

import javax.persistence.*;

@Entity
@Table(name="T6E3")
public class Employee3 {
    @Id
    int empId;

    @ManyToOne
    @JoinColumn(name="dept_id")
    Department3 department;

    @Embedded
    EmployeeName3 name;

    public int getEmpId() {
        return empId;
    }

    public void setEmpId(int empId) {
        this.empId = empId;
    }

    public Department3 getDepartment() {
        return department;
    }

    public void setDepartment(Department3 department) {
        this.department = department;
    }

    public EmployeeName3 getName() {
        return name;
    }

    public void setName(EmployeeName3 name) {
        this.name = name;
    }
}

==> openjpa-parent-4.1.1-source-release.zip: openjpa-parent-4.1.1/openjpa-persistence-jdbc/src/test/java/org/apache/openjpa/persistence/jdbc/maps/spec_10_1_26_ex0/Employee3.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.openjpa.persistence.jdbc.maps.spec_10_1_26_ex0;

import jakarta.persistence.Embedded;
import jakarta.persistence.Entity;
import jakarta.persistence.Id;
import jakarta.persistence.JoinColumn;
import jakarta.persistence.ManyToOne;
import jakarta.persistence.Table;

@Entity
@Table(name="T6E3")
public class Employee3 {
    @Id
    int empId;

    @ManyToOne
    @JoinColumn(name="dept_id")
    Department3 department;

    @Embedded
    EmployeeName3 name;

    public int getEmpId() {
        return empId;
    }

    public void setEmpId(int empId) {
        this.empId = empId;
    }

    public Department3 getDepartment() {
        return department;
    }

    public void setDepartment(Department3 department) {
        this.department = department;
    }

    public EmployeeName3 getName() {
        return name;
    }

    public void setName(EmployeeName3 name) {
        this.name = name;
    }
}
